import {
  csv,
  select,
  scaleLinear,
  scaleBand,
  area,
  axisBottom,
  axisLeft,
} from 'd3'; // Importing necessary D3 modules

const csvUrl =
  'https://gist.githubusercontent.com/Jamescruz424/12b93cbff894bab4365034f9f635aaaf/raw/ac129b6d76c6bf78a56173e5db34011b0b881b87/gistfile1.txt'; // Replace this with the URL to your top 10 companies dataset CSV file

// Function to parse each row of the CSV data
const parseRow = (d) => {
  d.market_capitalization_billions =
    +d.market_capitalization_billions;
  d.revenue_billions = +d.revenue_billions;
  d.profits_billions = +d.profits_billions;
  return d;
};

const width = 800;
const height = 500;
const margin = { top: 20, right: 30, bottom: 30, left: 60 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Main function to create the Area Chart
const main = async () => {
  const data = await csv(csvUrl, parseRow);

  // Define scales
  const xScale = scaleBand()
    .domain(data.map((d) => d.company_name))
    .range([margin.left, innerWidth + margin.left])
    .padding(0.1);

  const yScale = scaleLinear()
    .domain([
      0,
      Math.max(
        ...data.map(
          (d) => d.market_capitalization_billions,
        ),
      ),
    ])
    .range([innerHeight + margin.top, margin.top]);

  // Define the area generator
  const areaGenerator = area()
    .x(
      (d) =>
        xScale(d.company_name) + xScale.bandwidth() / 2,
    )
    .y0(innerHeight + margin.top)
    .y1((d) => yScale(d.market_capitalization_billions));

  // Append the area path
  svg
    .append('path')
    .datum(data)
    .attr('fill', 'lightblue')
    .attr('d', areaGenerator);

  // Add X-axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0, ${innerHeight + margin.top})`,
    )
    .call(axisBottom(xScale))
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('transform', 'rotate(-45)');

  // Add Y-axis
  svg
    .append('g')
    .attr('transform', `translate(${margin.left}, 0)`)
    .call(axisLeft(yScale));

  // Add labels for X-axis and Y-axis
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', height - margin.bottom / 2)
    .style('text-anchor', 'middle')
    .text('Company Name');

  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('x', 0 - height / 2)
    .attr('y', margin.left / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Market Capitalization (Billions)');
};

main(); // Calling the main function to create the Area Chart
